/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IPubSub } from "@fluidframework/server-memory-orderer";
import { IHistorian } from "@fluidframework/server-services-client";
import { IDatabaseManager, IDocumentStorage, ILogger, IOrderer, IOrdererManager, IServiceConfiguration, ITaskMessageSender, ITenantManager, TokenGenerator } from "@fluidframework/server-services-core";
export declare class LocalOrdererManager implements IOrdererManager {
    private readonly storage;
    private readonly databaseManager;
    private readonly tenantManager;
    private readonly taskMessageSender;
    private readonly permission;
    private readonly tokenGenerator;
    private readonly createHistorian;
    private readonly logger;
    private readonly serviceConfiguration?;
    private readonly pubsub?;
    /**
     * Map of "tenantId/documentId" to the orderer for that document.
     */
    private readonly ordererMap;
    constructor(storage: IDocumentStorage, databaseManager: IDatabaseManager, tenantManager: ITenantManager, taskMessageSender: ITaskMessageSender, permission: any, // Can probably remove
    tokenGenerator: TokenGenerator, createHistorian: (tenant: string) => Promise<IHistorian>, logger: ILogger, serviceConfiguration?: Partial<IServiceConfiguration> | undefined, pubsub?: IPubSub | undefined);
    /**
     * Closes all local orderers
     */
    close(): Promise<void>;
    /**
     * Returns true if there are any received ops that are not yet ordered.
     */
    hasPendingWork(): Promise<boolean>;
    getOrderer(tenantId: string, documentId: string): Promise<IOrderer>;
    private createLocalOrderer;
}
//# sourceMappingURL=localOrdererManager.d.ts.map